@@ -18,6 +18,7 @@
 */
 
 #include "cachecleaner.h"
+#include <akdebug.h>
 #include "storage/parthelper.h"
 #include "storage/datastore.h"
 #include "storage/selectquerybuilder.h"
@@ -70,7 +71,7 @@ void CacheCleaner::cleanCache()
     qb.addValueCondition( QString::fromLatin1( "substr( %1, 1, 4 )" ).arg( Part::nameFullColumnName() ), Query::Equals, QLatin1String( "PLD:" ) );
     qb.addValueCondition( PimItem::dirtyFullColumnName(), Query::Equals, false );
     QStringList localParts;
-    foreach ( const QString &partName, collection.cachePolicyLocalParts().split( QLatin1String( " " ) ) ) {
+    Q_FOREACH ( const QString &partName, collection.cachePolicyLocalParts().split( QLatin1String( " " ) ) ) {
       if ( partName.startsWith( QLatin1String( "PLD:" ) ) )
         localParts.append( partName );
       else
@@ -83,12 +84,12 @@ void CacheCleaner::cleanCache()
     const Part::List parts = qb.result();
     if ( parts.isEmpty() )
       continue;
-    qDebug() << "found" << parts.count() << "item parts to expire in collection" << collection.name();
+    akDebug() << "found" << parts.count() << "item parts to expire in collection" << collection.name();
 
     // clear data field
-    foreach ( Part part, parts ) {
+    Q_FOREACH ( Part part, parts ) {
       if ( !PartHelper::truncate( part ) )
-        qDebug() << "failed to update item part" << part.id();
+        akDebug() << "failed to update item part" << part.id();
     }
     loopsWithExpiredItem++;
   }
