@@ -94,7 +94,9 @@ bool ColCopy::parseStream()
   ItemRetriever retriever( connection() );
   retriever.setCollection( source, true );
   retriever.setRetrieveFullPayload( true );
-  retriever.exec();
+  if (!retriever.exec()) {
+    return failureResponse( retriever.lastError() );
+  }
 
   DataStore *store = connection()->storageBackend();
   Transaction transaction( store );
