@@ -38,8 +38,8 @@ bool Fetch::parseStream()
 
   FetchHelper fetchHelper( connection(), mScope );
   fetchHelper.setStreamParser( m_streamParser );
-  connect( &fetchHelper, SIGNAL( responseAvailable( const Response& ) ),
-           this, SIGNAL( responseAvailable( const Response& ) ) );
+  connect( &fetchHelper, SIGNAL(responseAvailable(Response)),
+           this, SIGNAL(responseAvailable(Response)) );
 
   if ( !fetchHelper.parseStream( "FETCH" ) )
     return false;
