@@ -24,6 +24,7 @@
 #include <QtCore/QUrl>
 #include <QMetaObject>
 
+#include <akdebug.h>
 #include "src/nepomuk/result.h"
 
 #include "entities.h"
@@ -63,7 +64,7 @@ NepomukSearchEngine::NepomukSearchEngine( QObject* parent )
     reloadSearches();
   } else {
     // FIXME: try to start the nepomuk server
-    qDebug() << "Nepomuk Query Server not available";
+    akError() << "Nepomuk Query Server not available";
   }
 }
 
@@ -78,6 +79,11 @@ void NepomukSearchEngine::addSearch( const Collection &collection )
     return;
   const QString &q = collection.queryString();
 
+  if ( q.size() >= 32768 ) {
+    qWarning() << "The query is at least 32768 chars long, which is the maximum size supported by the akonadi db schema. The query is therefore most likely truncated and will not be executed.";
+    return;
+  }
+
   //FIXME the requested property must be passed to here from the calling code
   //Ideally the Query is passed as object so we can check here for the akonadiItemId property, and add it if missing
   if (!q.contains(QString::fromLatin1("reqProp1")) || !q.contains(QString::fromLatin1("http://akonadi-project.org/ontologies/aneo#akonadiItemId"))) {
@@ -124,7 +130,7 @@ void NepomukSearchEngine::removeSearch( qint64 collectionId )
 
 void NepomukSearchEngine::reloadSearches()
 {
-  qDebug() << this << sender();
+  akDebug() << this << sender();
   SelectQueryBuilder<Collection> qb;
   qb.addValueCondition( Collection::queryLanguageFullColumnName(), Query::Equals, QLatin1String( "SPARQL" ) );
   if ( !qb.exec() ) {
@@ -136,11 +142,11 @@ void NepomukSearchEngine::reloadSearches()
     mMutex.lock();
     if ( mQueryInvMap.contains( collection.id() ) ) {
       mMutex.unlock();
-      qDebug() << "updating search" << collection.name();
+      akDebug() << "updating search" << collection.name();
       removeSearch( collection.id() );
     } else  {
       mMutex.unlock();
-      qDebug() << "adding search" << collection.name();
+      akDebug() << "adding search" << collection.name();
     }
     addSearch( collection );
   }
@@ -156,7 +162,7 @@ void NepomukSearchEngine::stopSearches()
   }
 
   Q_FOREACH ( const Collection &collection, qb.result() ) {
-    qDebug() << "removing search" << collection.name();
+    akDebug() << "removing search" << collection.name();
     removeSearch( collection.id() );
   }
 }
