@@ -299,6 +299,21 @@ static bool recursiveSetResourceId( const Collection & collection, qint64 resour
   QueryBuilder qb( Collection::tableName(), QueryBuilder::Update );
   qb.addValueCondition( Collection::parentIdColumn(), Query::Equals, collection.id() );
   qb.setColumnValue( Collection::resourceIdColumn(), resourceId );
+  qb.setColumnValue( Collection::remoteIdColumn(), QVariant() );
+  qb.setColumnValue( Collection::remoteRevisionColumn(), QVariant() );
+  if ( !qb.exec() )
+    return false;
+
+  // this is a cross-resource move, so also reset any resource-specific data (RID, RREV, etc)
+  // as well as mark the items dirty to prevent cache purging before they have been written back
+  qb = QueryBuilder( PimItem::tableName(), QueryBuilder::Update );
+  qb.addValueCondition( PimItem::collectionIdColumn(), Query::Equals, collection.id() );
+  qb.setColumnValue( PimItem::remoteIdColumn(), QVariant() );
+  qb.setColumnValue( PimItem::remoteRevisionColumn(), QVariant() );
+  const QDateTime now = QDateTime::currentDateTime();
+  qb.setColumnValue( PimItem::datetimeColumn(), now );
+  qb.setColumnValue( PimItem::atimeColumn(), now );
+  qb.setColumnValue( PimItem::dirtyColumn(), true );
   if ( !qb.exec() )
     return false;
 
@@ -331,6 +346,8 @@ bool Akonadi::DataStore::moveCollection( Collection & collection, const Collecti
   collection.setParentId( newParent.id() );
   if ( collection.resourceId() != resourceId ) {
     collection.setResourceId( resourceId );
+    collection.setRemoteId( QString() );
+    collection.setRemoteRevision( QString() );
     if ( !recursiveSetResourceId( collection, resourceId ) )
       return false;
   }
