@@ -31,7 +31,7 @@ class QueryBuilder;
 class QueryBuilderTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void testQueryBuilder_data();
     void testQueryBuilder();
 
